function [K_eff G_eff A_dil_K A_dil_G A_MT_K A_MT_G] = f_MT_incl_coated_output_including_factors(...
    c_matrix, c_uncoated, c_coated, c_coating,...
    K_matrix, K_uncoated, K_coated, K_coating,... 
    G_matrix, G_uncoated, G_coated, G_coating,...
    r_coated, r_coating)
%
% calculates effective stiffness (K_eff and G_eff) of the composite
% containing also coated particles
%
% f_MT_incl_coated(...
%   c_matrix, c_uncoated, c_coated, c_coating,...
%   K_matrix, K_uncoated, K_coated, K_coating,... 
%   G_matrix, G_uncoated, G_coated, G_coating,...
%   r_coated, r_coating)
%
% input: c - volumetric fractions [-]
%            - uncoated = uncoated particles
%            - coated = coated particles
%            - coating = corresponding coating of coated particles
%        K - bulk modulus [Pa]
%        G - shear modulus [Pa]
%        r - radius of particle and coating, respectively [m]
%
% output: effective bulk modulus K_eff [Pa]
%         effective shear modulus G_eff [Pa]
%
% written by Venca 30/04/2012

%% input processing

n_u = size(c_uncoated,1);     % number of uncoated particles + matrix
n_c = size(c_coated,1);       % number of coated particles
n_total = 1+n_u+n_c*2;

c_total = [c_matrix; c_uncoated; c_coated; c_coating];   % normal MT homogenization w/ uncoated particles
K_total = [K_matrix; K_uncoated; K_coated; K_coating];
G_total = [G_matrix; G_uncoated; G_coated; G_coating];

if n_c > 0
    nu_matrix = (3*K_matrix-2*G_matrix)/(2*(3*K_matrix+G_matrix));
    nu_coated = (3*K_coated-2*G_coated)./(2*(3*K_coated+G_coated));
    nu_coating = (3*K_coating-2*G_coating)./(2*(3*K_coating+G_coating));
end

%% constraint constants for uncoated particles

alpha_0 = 3*K_matrix/(3*K_matrix+4*G_matrix);
beta_0 = 6*(K_matrix+2*G_matrix)/(5*(3*K_matrix+4*G_matrix));

%% dilute concentration factors

A_dil_K = zeros(n_total,1);
A_dil_G = zeros(n_total,1);

if sum(c_uncoated) > 0
    for n = 1:n_u;
        A_dil_K(1+n) = 1/(1+alpha_0*(K_uncoated(n)/K_matrix-1));
        A_dil_G(1+n) = 1/(1+beta_0*(G_uncoated(n)/G_matrix-1));
    end
end

if n_c > 0
    for n = 1:n_c
        [TK TG] = f_strain_factors_layered_inclusion_Herve_Zaoui(2,...
            [K_coated(n);K_coating(n);K_matrix],... 
            [G_coated(n);G_coating(n);G_matrix],...
            [nu_coated(n);nu_coating(n);nu_matrix], [r_coated(n);r_coating(n)]);

        A_dil_K(1+n_u+n) = TK(1);
        A_dil_K(1+n_u+n_c+n) = TK(2);
        A_dil_G(1+n_u+n) = TG(1);
        A_dil_G(1+n_u+n_c+n) = TG(2);
    end
end

A_dil_K(1) = 1-sum(A_dil_K);
A_dil_G(1) = 1-sum(A_dil_G);

%% Mori-Tanaka factors

A_MT_K = c_matrix;
A_MT_G = c_matrix;
for i = 2:n_total
    A_MT_K = A_MT_K+c_total(i)*A_dil_K(i);
    A_MT_G = A_MT_G+c_total(i)*A_dil_G(i);
end
A_MT_K = 1/A_MT_K;
A_MT_G = 1/A_MT_G;

%% K_eff, G_eff

K_eff = c_matrix*K_matrix;
for i = 2:n_total
    K_eff = K_eff+c_total(i)*K_total(i)*A_dil_K(i);
end
K_eff = K_eff*A_MT_K;

G_eff = c_total(1)*G_matrix;
for i = 2:n_total
    G_eff = G_eff+c_total(i)*G_total(i)*A_dil_G(i);
end
G_eff = G_eff*A_MT_G;

end
